Welcome to ClientVPS Mirrors

Help for package KCSNBShiny
Type: Package
Title: Naive Bayes Classifier
Version: 0.1.0
Author: Karne Chaithanya Sai
Maintainer: Karne Chaithanya Sai <karnechaithanyasai@gmail.com>
Description: Predicts any variable in any categorical dataset for given values of predictor variables. If a dataset contains 4 variables, then any variable can be predicted based on the values of the other three variables given by the user. The user can upload their own datasets and select what variable they want to predict. A 'handsontable' is provided to enter the predictor values and also accuracy of the prediction is also shown.
License: GPL-2
LazyData: FALSE
URL: https://karnechaithanyasai.shinyapps.io/KCSNBShiny/
Encoding: UTF-8
Imports: shiny, rhandsontable, dplyr, caret, e1071,
RoxygenNote: 6.1.1
NeedsCompilation: no
Repository: CRAN
Packaged: 2019-06-28 16:32:49 UTC; Mahe
Date/Publication: 2019-07-01 12:20:03 UTC

Naive Bayes Classifier

Description

Predicts any variable in any categorical dataset for given values of predictor variables.If a dataset contains 4 variables, then any variable can be predicted based on the values of the other three variables given by the user. The user can upload their own datasets and select what variable they want to predict.A handsontable is provided to enter the predictor values and also accuracy of the prediction is also shown.

Usage

KCSNBShiny()

Examples

if(interactive()){KCSNBShiny()}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.